@@ -27,13 +27,15 @@ public:
   virtual int minimumHeight() const;
 
   virtual DomElement *createDomElement(bool fitWidth, bool fitHeight,
-				       int& additionalVerticalPadding,
 				       WApplication *app);
 
   static bool useJavaScriptHeights(WApplication *app);
 
   virtual void setHint(const std::string& name, const std::string& value);
 
+  // Does not really belong here, but who cares ?
+  static const char* childrenResizeJS();
+
 protected:
   virtual void containerAddWidgets(WContainerWidget *container);
 
