@@ -46,10 +46,18 @@
   #define WT_API
 #endif
 
-#ifdef JAVA
-#define WT_ARRAY volatile
-#else
+#ifndef WT_TARGET_JAVA
 #define WT_ARRAY
+#define W_JAVA_COMPARATOR(type)
+#define WT_USTRING WString
+#define WT_LOCALE std::string 
+#define WT_BOSTREAM std::ostream
+#else
+#define WT_ARRAY volatile
+#define W_JAVA_COMPARATOR(type) : public Comparator<type>
+#define WT_USTRING std::string
+#define WT_LOCALE Locale 
+#define WT_BOSTREAM std::bostream
 #endif
 
 #ifdef WIN32
