@@ -4,8 +4,8 @@
  *
  * See the LICENSE file for terms of use.
  */
-#ifndef HTTP_REQUEST_H_
-#define HTTP_REQUEST_H_
+#ifndef HTTP_HTTP_REQUEST_H_
+#define HTTP_HTTP_REQUEST_H_
 
 #include <sstream>
 
@@ -20,12 +20,15 @@ class HTTPRequest : public Wt::WebRequest
 public:
   HTTPRequest(WtReplyPtr wtReply);
 
-  virtual void flush();
+  virtual void flush(ResponseState state, CallbackFunction callback = 0,
+		     void *callbackData = 0);
 
   virtual std::istream& in() { return instream_; }
   virtual std::ostream& out() { return outstream_; }
   virtual std::ostream& err() { return std::cerr; }
 
+  virtual void setStatus(int status);
+
   virtual void addHeader(const std::string& name, const std::string& value);
   virtual void setContentType(const std::string& value);
   virtual void setRedirect(const std::string& url);
@@ -43,11 +46,11 @@ public:
 
 private:
   WtReplyPtr reply_;
-  std::stringstream instream_;
+  std::istream &instream_;
   std::stringstream outstream_;
 };
 
 }
 }
 
-#endif // HTTPRequest
+#endif // HTTP_HTTP_REQUEST_H_
