@@ -13,16 +13,30 @@
 
 namespace Wt {
 
+/*
+ * A simple template streaming class.
+ *
+ * It supports:
+ * - variables (_$_name_$_)
+ * - conditions:
+ *  _$_$if_condition_$_
+ *     ...
+ *  _$_$endif_$_
+ * and
+ *  _$_$ifnot_condition_$_;
+ *     ...
+ *  _$_$endif_$_;
+ */
 class FileServe
 {
 public:
   FileServe(const char *contents);
 
-  const char *contents() const { return template_; }
-
   void setVar(const std::string& name, const std::string& value);
   void setVar(const std::string& name, const char *value);
   void setVar(const std::string& name, bool value);
+  void setVar(const std::string& name, int value);
+  void setCondition(const std::string& name, bool value);
   void stream(std::ostream& out);
   void streamUntil(std::ostream& out, const std::string& until);
 
@@ -30,6 +44,7 @@ private:
   const char *template_;
   int currentPos_;
   std::map<std::string, std::string> vars_;
+  std::map<std::string, bool> conditions_;
 };
 
 }
